Generalized Matthew Corrlelation  Coefficient (MCC)

This package offers tools for calcualting (MCC)  
https://towardsdatascience.com/the-best-classification-metric-youve-never-heard-of-the-matthews-correlation-coefficient-3bf50a2f3e9a

The purpose was taking the knwon MCC and extending it to work on multi-class problems
In the init you can do one of the following:
1  Leave the avg_type empty - It will run the ggeneralized Matthew
2  Put 2 which will work similarly to clause 1
3 Put 3 which will run case The gneralized F1
